==> stable-2.6.5.zip: essentials/Essentials/src/com/earth2me/essentials/settings/Settings.java <==
package com.earth2me.essentials.settings;

import com.earth2me.essentials.storage.Comment;
import com.earth2me.essentials.storage.StorageObject;
import lombok.Data;
import lombok.EqualsAndHashCode;


@Data
@EqualsAndHashCode(callSuper = false)
public class Settings extends StorageObject
{
	@Comment(
	{
		"##########################################################",
		"+------------------------------------------------------+ #",
		"|                 General Settings                     | #",
		"+------------------------------------------------------+ #",
		"##########################################################"
	})
	private General general = new General();
	@Comment(
	{
		"##########################################################",
		"+------------------------------------------------------+ #",
		"|                  Chat Settings                       | #",
		"+------------------------------------------------------+ #",
		"##########################################################"
	})
	private Chat chat = new Chat();
	@Comment(
	{
		"##########################################################",
		"+------------------------------------------------------+ #",
		"|                 Economy Settings                     | #",
		"+------------------------------------------------------+ #",
		"##########################################################"
	})
	private Economy economy = new Economy();
	@Comment(
	{
		"##########################################################",
		"+------------------------------------------------------+ #",
		"|                 Commands Settings                    | #",
		"+------------------------------------------------------+ #",
		"##########################################################"
	})
	private Commands commands = new Commands();
	@Comment(
	{
		"##########################################################",
		"+------------------------------------------------------+ #",
		"|                  Group Settings                      | #",
		"+------------------------------------------------------+ #",
		"##########################################################"
	})
	private Groups groups = new Groups();
}

==> stable-2.7.1.zip: essentials/Essentials/src/com/earth2me/essentials/settings/Settings.java <==
package com.earth2me.essentials.settings;

import com.earth2me.essentials.storage.Comment;
import com.earth2me.essentials.storage.StorageObject;
import lombok.Data;
import lombok.EqualsAndHashCode;


@Data
@EqualsAndHashCode(callSuper = false)
public class Settings implements StorageObject
{
	@Comment(
	{
		"##########################################################",
		"+------------------------------------------------------+ #",
		"|                 General Settings                     | #",
		"+------------------------------------------------------+ #",
		"##########################################################"
	})
	private General general = new General();
	@Comment(
	{
		"##########################################################",
		"+------------------------------------------------------+ #",
		"|                  Chat Settings                       | #",
		"+------------------------------------------------------+ #",
		"##########################################################"
	})
	private Chat chat = new Chat();
	@Comment(
	{
		"##########################################################",
		"+------------------------------------------------------+ #",
		"|                 Economy Settings                     | #",
		"+------------------------------------------------------+ #",
		"##########################################################"
	})
	private Economy economy = new Economy();
	@Comment(
	{
		"##########################################################",
		"+------------------------------------------------------+ #",
		"|                 Commands Settings                    | #",
		"+------------------------------------------------------+ #",
		"##########################################################"
	})
	private Commands commands = new Commands();
	@Comment(
	{
		"##########################################################",
		"+------------------------------------------------------+ #",
		"|                  Group Settings                      | #",
		"+------------------------------------------------------+ #",
		"##########################################################"
	})
	private Groups groups = new Groups();
}
